@@ -11,7 +11,7 @@ class InvalidApiKeyPassed(Exception): pass
 
 
 # major.minor.patch.commit
-MSDK_VERSION = "0.1.2.4"
+MSDK_VERSION = "0.1.4.6"
 
 
 def check_invalid_api_key(request_data):
@@ -66,6 +66,9 @@ def post_files(url, filename1=None, filename2=None, **kwargs):
     headers = kwargs.get("headers", None)
     proxy = kwargs.get("proxy", None)
 
+    if proxy is None:
+        proxy = {}
+
     assert headers is not None
     assert type(proxy) == dict
     assert filename1 is not None
